@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2024 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -76,7 +76,7 @@ void genie_long_mp_max_int (NODE_T * p)
 
 void genie_long_max_real (NODE_T * p)
 {
-  unt digs = DIGITS (M_LONG_REAL);
+  int digs = DIGITS (M_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_EXPONENT (z) = (MP_T) (MAX_MP_EXPONENT - 1);
@@ -89,7 +89,7 @@ void genie_long_max_real (NODE_T * p)
 
 void genie_long_mp_max_real (NODE_T * p)
 {
-  unt digs = DIGITS (M_LONG_LONG_REAL);
+  int digs = DIGITS (M_LONG_LONG_REAL);
   MP_T *z = nil_mp (p, digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_EXPONENT (z) = (MP_T) (MAX_MP_EXPONENT - 1);
@@ -133,8 +133,8 @@ void genie_long_mp_small_real (NODE_T * p)
 void genie_lengthen_int_to_mp (NODE_T * p)
 {
   int digs = DIGITS (M_LONG_INT);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
   MP_T *z = nil_mp (p, digs);
   (void) int_to_mp (p, z, VALUE (&k), digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
@@ -149,7 +149,7 @@ void genie_shorten_mp_to_int (NODE_T * p)
   DECREMENT_STACK_POINTER (p, size);
   MP_T *z = (MP_T *) STACK_TOP;
   MP_STATUS (z) = (MP_T) INIT_MASK;
-  PUSH_VALUE (p, mp_to_int (p, z, digs), A68_INT);
+  PUSH_VALUE (p, mp_to_int (p, z, digs), A68G_INT);
 }
 
 //! @brief OP LENG = (REAL) LONG REAL
@@ -157,8 +157,8 @@ void genie_shorten_mp_to_int (NODE_T * p)
 void genie_lengthen_real_to_mp (NODE_T * p)
 {
   int digs = DIGITS (M_LONG_REAL);
-  A68_REAL x;
-  POP_OBJECT (p, &x, A68_REAL);
+  A68G_REAL x;
+  POP_OBJECT (p, &x, A68G_REAL);
   MP_T *z = nil_mp (p, digs);
   (void) real_to_mp (p, z, VALUE (&x), digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
@@ -173,7 +173,7 @@ void genie_shorten_mp_to_real (NODE_T * p)
   DECREMENT_STACK_POINTER (p, size);
   MP_T *z = (MP_T *) STACK_TOP;
   MP_STATUS (z) = (MP_T) INIT_MASK;
-  PUSH_VALUE (p, mp_to_real (p, z, digs), A68_REAL);
+  PUSH_VALUE (p, mp_to_real (p, z, digs), A68G_REAL);
 }
 
 //! @brief OP ENTIER = (LONG REAL) LONG INT
@@ -181,20 +181,20 @@ void genie_shorten_mp_to_real (NODE_T * p)
 void genie_entier_mp (NODE_T * p)
 {
   int digs = DIGITS (LHS_MODE (p)), size = SIZE (LHS_MODE (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   (void) entier_mp (p, z, z, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 #define C_L_FUNCTION(p, f)\
   int digs = DIGITS (MOID (p)), size = SIZE (MOID (p));\
-  ADDR_T pop_sp = A68_SP;\
+  ADDR_T pop_sp = A68G_SP;\
   MP_T *x = (MP_T *) STACK_OFFSET (-size);\
   errno = 0;\
   PRELUDE_ERROR (f (p, x, x, digs) == NaN_MP || errno != 0, p, ERROR_INVALID_ARGUMENT, MOID (p));\
   MP_STATUS (x) = (MP_T) INIT_MASK;\
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 
 //! @brief PROC (LONG REAL) LONG REAL long sqrt
 
@@ -267,7 +267,7 @@ void genie_beta_mp (NODE_T * p)
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   PRELUDE_ERROR (beta_mp (p, a, a, b, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
-  A68_SP -= size;
+  A68G_SP -= size;
   MP_STATUS (a) = (MP_T) INIT_MASK;
 }
 
@@ -279,7 +279,7 @@ void genie_lnbeta_mp (NODE_T * p)
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   PRELUDE_ERROR (lnbeta_mp (p, a, a, b, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
-  A68_SP -= size;
+  A68G_SP -= size;
   MP_STATUS (a) = (MP_T) INIT_MASK;
 }
 
@@ -292,7 +292,7 @@ void genie_beta_inc_mp (NODE_T * p)
   MP_T *t = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *s = (MP_T *) STACK_OFFSET (-3 * size);
   PRELUDE_ERROR (beta_inc_mp (p, s, s, t, x, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
-  A68_SP -= 2 * size;
+  A68G_SP -= 2 * size;
   MP_STATUS (s) = (MP_T) INIT_MASK;
 }
 
@@ -409,7 +409,7 @@ void genie_atan2_mp (NODE_T * p)
   MP_T *y = (MP_T *) STACK_OFFSET (-size);
   MP_T *x = (MP_T *) STACK_OFFSET (-2 * size);
   PRELUDE_ERROR (atan2_mp (p, x, y, x, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
-  A68_SP -= size;
+  A68G_SP -= size;
   MP_STATUS (x) = (MP_T) INIT_MASK;
 }
 
@@ -420,7 +420,7 @@ void genie_atan2_mp (NODE_T * p)
 void genie_lengthen_mp_to_long_mp (NODE_T * p)
 {
   DECREMENT_STACK_POINTER (p, (int) size_mp ());
-  MP_T *z = (MP_T *) STACK_ADDRESS (A68_SP);
+  MP_T *z = (MP_T *) STACK_ADDRESS (A68G_SP);
   z = len_mp (p, z, mp_digits (), long_mp_digits ());
   MP_STATUS (z) = (MP_T) INIT_MASK;
 }
@@ -443,7 +443,7 @@ void genie_shorten_long_mp_to_mp (NODE_T * p)
 
 void genie_minus_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
@@ -453,7 +453,7 @@ void genie_minus_mp (NODE_T * p)
 
 void genie_abs_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
@@ -463,10 +463,10 @@ void genie_abs_mp (NODE_T * p)
 
 void genie_sign_mp (NODE_T * p)
 {
-  int size = SIZE (LHS_MODE (p));
+  size_t size = SIZE (LHS_MODE (p));
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   DECREMENT_STACK_POINTER (p, size);
-  PUSH_VALUE (p, SIGN (MP_DIGIT (z, 1)), A68_INT);
+  PUSH_VALUE (p, SIGN (MP_DIGIT (z, 1)), A68G_INT);
 }
 
 //! @brief OP + = (LONG MODE, LONG MODE) LONG MODE
@@ -601,24 +601,24 @@ void genie_modab_mp (NODE_T * p)
 
 // OP (LONG MODE, LONG MODE) BOOL.
 
-#define A68_CMP_LONG(n, OP)\
+#define A68G_CMP_LONG(n, OP)\
 void n (NODE_T * p) {\
   MOID_T *mode = LHS_MODE (p);\
-  A68_BOOL z;\
+  A68G_BOOL z;\
   int digs = DIGITS (mode), size = SIZE (mode);\
   MP_T *x = (MP_T *) STACK_OFFSET (-2 * size);\
   MP_T *y = (MP_T *) STACK_OFFSET (-size);\
   OP (p, &z, x, y, digs);\
   DECREMENT_STACK_POINTER (p, 2 * size);\
-  PUSH_VALUE (p, VALUE (&z), A68_BOOL);\
+  PUSH_VALUE (p, VALUE (&z), A68G_BOOL);\
 }
 
-A68_CMP_LONG (genie_eq_mp, eq_mp);
-A68_CMP_LONG (genie_ne_mp, ne_mp);
-A68_CMP_LONG (genie_lt_mp, lt_mp);
-A68_CMP_LONG (genie_gt_mp, gt_mp);
-A68_CMP_LONG (genie_le_mp, le_mp);
-A68_CMP_LONG (genie_ge_mp, ge_mp);
+A68G_CMP_LONG (genie_eq_mp, eq_mp);
+A68G_CMP_LONG (genie_ne_mp, ne_mp);
+A68G_CMP_LONG (genie_lt_mp, lt_mp);
+A68G_CMP_LONG (genie_gt_mp, gt_mp);
+A68G_CMP_LONG (genie_le_mp, le_mp);
+A68G_CMP_LONG (genie_ge_mp, ge_mp);
 
 //! @brief OP ** = (LONG MODE, INT) LONG MODE
 
@@ -626,8 +626,8 @@ void genie_pow_mp_int (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int digs = DIGITS (mode), size = SIZE (mode);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   (void) pow_mp_int (p, x, x, VALUE (&k), digs);
   MP_STATUS (x) = (MP_T) INIT_MASK;
@@ -639,19 +639,19 @@ void genie_pow_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int digs = DIGITS (mode), size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *y = (MP_T *) STACK_OFFSET (-size);
   if (IS_ZERO_MP (x)) {
     if (MP_DIGIT (y, 1) < (MP_T) 0) {
-      PRELUDE_ERROR (A68_TRUE, p, ERROR_INVALID_ARGUMENT, MOID (p));
+      PRELUDE_ERROR (A68G_TRUE, p, ERROR_INVALID_ARGUMENT, MOID (p));
     } else if (IS_ZERO_MP (y)) {
       SET_MP_ONE (x, digs);
     }
   } else {
     (void) pow_mp (p, x, x, y, digs);
   }
-  A68_SP = pop_sp - size;
+  A68G_SP = pop_sp - size;
   MP_STATUS (x) = (MP_T) INIT_MASK;
 }
 
@@ -664,9 +664,9 @@ void genie_odd_mp (NODE_T * p)
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   DECREMENT_STACK_POINTER (p, size);
   if (MP_EXPONENT (z) <= (MP_T) (digs - 1)) {
-    PUSH_VALUE (p, (BOOL_T) ! EVEN ((MP_INT_T) (z[(int) (2 + MP_EXPONENT (z))])), A68_BOOL);
+    PUSH_VALUE (p, (BOOL_T) ! EVEN ((MP_INT_T) (z[(int) (2 + MP_EXPONENT (z))])), A68G_BOOL);
   } else {
-    PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+    PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
   }
 }
 
@@ -725,8 +725,8 @@ void genie_pow_mp_int_int (NODE_T * p)
 {
   MOID_T *m = LHS_MODE (p);
   int digs = DIGITS (m), size = SIZE (m);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   (void) pow_mp_int (p, x, x, VALUE (&k), digs);
   test_mp_int_range (p, x, m);
@@ -763,21 +763,21 @@ void genie_round_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int digs = DIGITS (mode), size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   (void) round_mp (p, z, z, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 #define C_CL_FUNCTION(p, f)\
   MOID_T *mode = MOID (p);\
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);\
-  ADDR_T pop_sp = A68_SP;\
+  ADDR_T pop_sp = A68G_SP;\
   MP_T *im = (MP_T *) STACK_OFFSET (-size);\
   MP_T *re = (MP_T *) STACK_OFFSET (-2 * size);\
   errno = 0;\
   (void) f(p, re, im, digs);\
-  A68_SP = pop_sp;\
+  A68G_SP = pop_sp;\
   MP_STATUS (re) = (MP_T) INIT_MASK;\
   MP_STATUS (im) = (MP_T) INIT_MASK;\
   MATH_RTE (p, errno != 0, mode, NO_TEXT);\
@@ -892,9 +892,9 @@ void genie_atanh_mp_complex (NODE_T * p)
 void genie_lengthen_complex_to_mp_complex (NODE_T * p)
 {
   int digs = DIGITS (M_LONG_REAL);
-  A68_REAL a, b;
-  POP_OBJECT (p, &b, A68_REAL);
-  POP_OBJECT (p, &a, A68_REAL);
+  A68G_REAL a, b;
+  POP_OBJECT (p, &b, A68G_REAL);
+  POP_OBJECT (p, &a, A68G_REAL);
   MP_T *z = nil_mp (p, digs);
   (void) real_to_mp (p, z, VALUE (&a), digs);
   MP_STATUS (z) = (MP_T) INIT_MASK;
@@ -911,8 +911,8 @@ void genie_shorten_mp_complex_to_complex (NODE_T * p)
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   DECREMENT_STACK_POINTER (p, 2 * size);
-  PUSH_VALUE (p, mp_to_real (p, a, digs), A68_REAL);
-  PUSH_VALUE (p, mp_to_real (p, b, digs), A68_REAL);
+  PUSH_VALUE (p, mp_to_real (p, a, digs), A68G_REAL);
+  PUSH_VALUE (p, mp_to_real (p, b, digs), A68G_REAL);
 }
 
 //! @brief OP LENG = (LONG COMPLEX) LONG LONG COMPLEX
@@ -921,14 +921,14 @@ void genie_lengthen_mp_complex_to_long_mp_complex (NODE_T * p)
 {
   int digs = DIGITS (M_LONG_REAL), size = SIZE (M_LONG_REAL);
   int gdigs = DIGITS (M_LONG_LONG_REAL), size_g = SIZE (M_LONG_LONG_REAL);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = len_mp (p, a, digs, gdigs);
   MP_T *d = len_mp (p, b, digs, gdigs);
   (void) move_mp (a, c, gdigs);
   (void) move_mp (&a[LEN_MP (gdigs)], d, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   INCREMENT_STACK_POINTER (p, 2 * (size_g - size));
 }
 
@@ -938,12 +938,12 @@ void genie_shorten_long_mp_complex_to_mp_complex (NODE_T * p)
 {
   int digs = DIGITS (M_LONG_REAL), size = SIZE (M_LONG_REAL);
   int gdigs = DIGITS (M_LONG_LONG_REAL), size_g = SIZE (M_LONG_LONG_REAL);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *b = (MP_T *) STACK_OFFSET (-size_g);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size_g);
   (void) shorten_mp (p, a, digs, a, gdigs);
   (void) shorten_mp (p, &a[LEN_MP (digs)], digs, b, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_STATUS (a) = (MP_T) INIT_MASK;
   MP_STATUS (&a[LEN_MP (digs)]) = (MP_T) INIT_MASK;
   DECREMENT_STACK_POINTER (p, 2 * (size_g - size));
@@ -953,7 +953,7 @@ void genie_shorten_long_mp_complex_to_mp_complex (NODE_T * p)
 
 void genie_re_mp_complex (NODE_T * p)
 {
-  int size = SIZE (SUB_MOID (p));
+  size_t size = SIZE (SUB_MOID (p));
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   DECREMENT_STACK_POINTER (p, size);
@@ -976,7 +976,7 @@ void genie_im_mp_complex (NODE_T * p)
 
 void genie_minus_mp_complex (NODE_T * p)
 {
-  int size = SIZE_COMPL (SUB_MOID (p));
+  size_t size = SIZE_COMPL (SUB_MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_DIGIT (a, 1) = -MP_DIGIT (a, 1);
@@ -989,7 +989,7 @@ void genie_minus_mp_complex (NODE_T * p)
 
 void genie_conj_mp_complex (NODE_T * p)
 {
-  int size = SIZE_COMPL (SUB_MOID (p));
+  size_t size = SIZE_COMPL (SUB_MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_DIGIT (b, 1) = -MP_DIGIT (b, 1);
@@ -1003,13 +1003,13 @@ void genie_abs_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS (mode), size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *z = nil_mp (p, digs);
   errno = 0;
   (void) hypot_mp (p, z, a, b, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, size);
   (void) move_mp (a, z, digs);
   MP_STATUS (a) = (MP_T) INIT_MASK;
@@ -1022,13 +1022,13 @@ void genie_arg_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS (mode), size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *z = nil_mp (p, digs);
   errno = 0;
   (void) atan2_mp (p, z, a, b, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, size);
   (void) move_mp (a, z, digs);
   MP_STATUS (a) = (MP_T) INIT_MASK;
@@ -1041,7 +1041,7 @@ void genie_add_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
@@ -1050,7 +1050,7 @@ void genie_add_mp_complex (NODE_T * p)
   (void) add_mp (p, a, a, c, digs);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   MP_STATUS (b) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
 }
 
@@ -1060,7 +1060,7 @@ void genie_sub_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
@@ -1069,7 +1069,7 @@ void genie_sub_mp_complex (NODE_T * p)
   (void) sub_mp (p, a, a, c, digs);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   MP_STATUS (b) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
 }
 
@@ -1079,7 +1079,7 @@ void genie_mul_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
@@ -1087,7 +1087,7 @@ void genie_mul_mp_complex (NODE_T * p)
   (void) cmul_mp (p, a, b, c, d, digs);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   MP_STATUS (b) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
 }
 
@@ -1097,7 +1097,7 @@ void genie_div_mp_complex (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
@@ -1105,7 +1105,7 @@ void genie_div_mp_complex (NODE_T * p)
   PRELUDE_ERROR (cdiv_mp (p, a, b, c, d, digs) == NaN_MP, p, ERROR_DIVISION_BY_ZERO, mode);
   MP_STATUS (a) = (MP_T) INIT_MASK;
   MP_STATUS (b) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
 }
 
@@ -1115,9 +1115,9 @@ void genie_pow_mp_complex_int (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int digs = DIGITS_COMPL (mode), size = SIZE_COMPL (mode);
-  A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
-  ADDR_T pop_sp = A68_SP;
+  A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
+  ADDR_T pop_sp = A68G_SP;
   MP_T *im_x = (MP_T *) STACK_OFFSET (-size);
   MP_T *re_x = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *re_z = lit_mp (p, 1, 0, digs);
@@ -1152,7 +1152,7 @@ void genie_pow_mp_complex_int (NODE_T * p)
     (void) move_mp (re_y, rea, digs);
     expo <<= 1;
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   if (negative) {
     SET_MP_ONE (re_x, digs);
     SET_MP_ZERO (im_x, digs);
@@ -1171,16 +1171,16 @@ void genie_pow_mp_complex_int (NODE_T * p)
 void genie_eq_mp_complex (NODE_T * p)
 {
   int digs = DIGITS_COMPL (LHS_MODE (p)), size = SIZE_COMPL (LHS_MODE (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
   MP_T *a = (MP_T *) STACK_OFFSET (-4 * size);
   (void) sub_mp (p, b, b, d, digs);
   (void) sub_mp (p, a, a, c, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 4 * size);
-  PUSH_VALUE (p, (BOOL_T) (MP_DIGIT (a, 1) == 0 && MP_DIGIT (b, 1) == 0), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (MP_DIGIT (a, 1) == 0 && MP_DIGIT (b, 1) == 0), A68G_BOOL);
 }
 
 //! @brief OP /= = (LONG COMPLEX, LONG COMPLEX) BOOL
@@ -1188,16 +1188,16 @@ void genie_eq_mp_complex (NODE_T * p)
 void genie_ne_mp_complex (NODE_T * p)
 {
   int digs = DIGITS_COMPL (LHS_MODE (p)), size = SIZE_COMPL (LHS_MODE (p));
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *d = (MP_T *) STACK_OFFSET (-size);
   MP_T *c = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *b = (MP_T *) STACK_OFFSET (-3 * size);
   MP_T *a = (MP_T *) STACK_OFFSET (-4 * size);
   (void) sub_mp (p, b, b, d, digs);
   (void) sub_mp (p, a, a, c, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 4 * size);
-  PUSH_VALUE (p, (BOOL_T) (MP_DIGIT (a, 1) != 0 || MP_DIGIT (b, 1) != 0), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (MP_DIGIT (a, 1) != 0 || MP_DIGIT (b, 1) != 0), A68G_BOOL);
 }
 
 //! @brief OP +:= = (REF LONG COMPLEX, LONG COMPLEX) REF LONG COMPLEX
@@ -1378,7 +1378,7 @@ void genie_atan2dg_mp (NODE_T * p)
   MP_T *y = (MP_T *) STACK_OFFSET (-size);
   MP_T *x = (MP_T *) STACK_OFFSET (-2 * size);
   PRELUDE_ERROR (atan2dg_mp (p, x, y, x, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
-  A68_SP -= size;
+  A68G_SP -= size;
   MP_STATUS (x) = (MP_T) INIT_MASK;
 }
 
